import React, { useState, useCallback } from "react";
import { useFlipGroup } from "./hook";
import "./styles.css";

const shuffle = function shuffle(array) {
  for (let i = array.length - 1; i > 0; i--) {
    let j = Math.floor(Math.random() * (i + 1));
    [array[i], array[j]] = [array[j], array[i]];
  }
  return array;
};

const itemCollection = [
  { id: "a", text: "This is random string number 1" },
  { id: "b", text: "This is random string number 2" },
  { id: "c", text: "This is random string number 3" },
  { id: "d", text: "This is random string number 4" },
  { id: "e", text: "This is random string number 5" },
  { id: "f", text: "This is random string number 6" },
  { id: "g", text: "This is random string number 7" },
  { id: "h", text: "This is random string number 8" },
  { id: "i", text: "This is random string number 9" }
];

export default function App() {
  const [items, setItems] = useState(itemCollection);
  const [buttonClickable, setButtonClickable] = useState(true);

  const flipId = "flipRoot";

  const onTransitionEnd = useCallback(() => {
    setButtonClickable(true);
  }, []);

  useFlipGroup({
    flipId,
    opts: { duration: 700, easing: "cubic-bezier(0.68, -0.55, 0.265, 1.55)" },
    onTransitionEnd,
    deps: items
  });

  const shuffleItems = function shuffleItems() {
    let result = shuffle([...items]);
    setItems(result);
    setButtonClickable(false);
  };

  const sortItems = function sortItems() {
    const result = [...items].sort(
      (a, b) => a.id.charCodeAt(0) - b.id.charCodeAt(0)
    );
    setItems(result);
    setButtonClickable(false);
  };

  return (
    <div className="container">
      <section>
        <button
          disabled={!buttonClickable}
          className="shuffle"
          onClick={shuffleItems}
        >
          Shuffle
        </button>
        <button
          disabled={!buttonClickable}
          className="shuffle"
          onClick={sortItems}
        >
          Sort
        </button>
      </section>
      <div id={flipId} className="vroot">
        {items.map(item => {
          return (
            <div className={"vitem"} data-id={item.id} key={item.id}>
              {item.text}
            </div>
          );
        })}
      </div>
    </div>
  );
}
